Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(137)

Unified Diff: src/trusted/service_runtime/arch/arm/sel_rt.h

Issue 10806080: ARM: Rename the "new_eip" field in NaClThreadContext to "new_prog_ctr" (Closed) Base URL: svn://svn.chromium.org/native_client/trunk/src/native_client
Patch Set: Rebase + copyright Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/trusted/service_runtime/arch/arm/sel_rt.h
diff --git a/src/trusted/service_runtime/arch/arm/sel_rt.h b/src/trusted/service_runtime/arch/arm/sel_rt.h
index 94c0eab618da5975322b8967cdddd5e161c02795..bfa7a8ad3137346473641ed8fa9aad78026f2dcb 100644
--- a/src/trusted/service_runtime/arch/arm/sel_rt.h
+++ b/src/trusted/service_runtime/arch/arm/sel_rt.h
@@ -33,13 +33,13 @@ struct NaClThreadContext {
nacl_reg_t r4, r5, r6, r7, r8, r9, r10, fp, stack_ptr, prog_ctr;
/* 0 4 8 c 10 14 18 1c 20 24 */
/*
* sys_ret and new_eip are not a part of the thread's register set,
* but are needed by NaClSwitch. By including them here, the two
* use the same interface.
*/
uint32_t sysret;
/* 28 */
- uint32_t new_eip;
+ uint32_t new_prog_ctr;
/* 2c */
uint32_t tls_idx;
/* 30 */
@@ -33,13 +33,13 @@ struct NaClThreadContext {
/* 0 4 8 c 10 14 18 1c 20 24 */
/*
- * sys_ret and new_eip are not a part of the thread's register set,
- * but are needed by NaClSwitch. By including them here, the two
- * use the same interface.
+ * sys_ret and new_prog_ctr are not a part of the thread's register
+ * set, but are needed by NaClSwitch. By including them here, the
+ * two use the same interface.
*/
uint32_t sysret;
« no previous file with comments | « src/trusted/service_runtime/arch/arm/nacl_switch_to_app_arm.c ('k') | src/trusted/service_runtime/arch/arm/sel_rt.c » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698